import type { ECommitMode } from "../../domain/enum/commit-mode.enum.js";
import type { ICliInterfaceService } from "../interface/cli-interface-service.interface.js";
import type { IConfigService } from "../interface/config-service.interface.js";
import { LLMConfiguration } from "../../domain/entity/llm-configuration.entity.js";
/**
 * Use case for configuring LLM settings
 */
export declare class ConfigureLLMUseCase {
    private readonly CLI_INTERFACE;
    private readonly CONFIG_SERVICE;
    constructor(configService: IConfigService, cliInterface: ICliInterfaceService);
    /**
     * Configure LLM settings interactively
     * @returns Promise resolving to the new configuration
     */
    configureInteractively(): Promise<LLMConfiguration>;
    /**
     * Get the current LLM configuration
     * @returns Promise resolving to the current configuration or null if not configured
     */
    getCurrentConfiguration(): Promise<LLMConfiguration | null>;
    /**
     * Check if the current configuration needs LLM details
     * @returns Promise resolving to true if LLM details are needed
     */
    needsLLMDetails(): Promise<boolean>;
    /**
     * Save LLM configuration
     * @param configuration - The configuration to save
     */
    saveConfiguration(configuration: LLMConfiguration): Promise<void>;
    /**
     * Update the commit mode
     * @param mode - The new commit mode
     * @returns Promise resolving to the updated configuration
     */
    updateMode(mode: ECommitMode): Promise<LLMConfiguration | null>;
}
//# sourceMappingURL=configure-llm.use-case.d.ts.map