import type { ECommitMode } from "../enum/commit-mode.enum.js";
import type { ELLMProvider } from "../enum/llm-provider.enum.js";
import type { ApiKey } from "../value-object/api-key.value-object.js";
/**
 * Entity representing LLM configuration
 */
export declare class LLMConfiguration {
    private readonly API_KEY;
    private readonly MAX_RETRIES;
    private readonly MODE;
    private readonly MODEL;
    private readonly PROVIDER;
    private readonly VALIDATION_MAX_RETRIES;
    constructor(provider: ELLMProvider, apiKey: ApiKey, mode: ECommitMode, model?: string, maxRetries?: number, validationMaxRetries?: number);
    /**
     * Get the API key
     * @returns The API key
     */
    getApiKey(): ApiKey;
    /**
     * Get the maximum number of retries for LLM calls
     * @returns The maximum number of retries
     */
    getMaxRetries(): number;
    /**
     * Get the commit mode
     * @returns The commit mode
     */
    getMode(): ECommitMode;
    /**
     * Get the model name
     * @returns The model name
     */
    getModel(): string | undefined;
    /**
     * Get the LLM provider
     * @returns The LLM provider
     */
    getProvider(): ELLMProvider;
    /**
     * Get the maximum number of retries for validation fixes
     * @returns The maximum number of retries for validation
     */
    getValidationMaxRetries(): number;
    /**
     * Check if configuration is in auto mode
     * @returns True if in auto mode
     */
    isAutoMode(): boolean;
    /**
     * Check if configuration is in manual mode
     * @returns True if in manual mode
     */
    isManualMode(): boolean;
    /**
     * Create a new configuration with a different mode
     * @param mode - The new mode
     * @returns New configuration with the updated mode
     */
    withMode(mode: ECommitMode): LLMConfiguration;
    /**
     * Create a new configuration with updated model
     */
    withModel(model: string): LLMConfiguration;
}
//# sourceMappingURL=llm-configuration.entity.d.ts.map