'use strict';

var numeric_constant = require('../constant/numeric.constant.js');

/**
 * Entity representing LLM configuration
 */
class LLMConfiguration {
    API_KEY;
    MAX_RETRIES;
    MODE;
    MODEL;
    PROVIDER;
    VALIDATION_MAX_RETRIES;
    constructor(provider, apiKey, mode, model, maxRetries = numeric_constant.DEFAULT_MAX_RETRIES, validationMaxRetries = numeric_constant.DEFAULT_VALIDATION_MAX_RETRIES) {
        this.PROVIDER = provider;
        this.API_KEY = apiKey;
        this.MODE = mode;
        this.MODEL = model;
        this.MAX_RETRIES = maxRetries;
        this.VALIDATION_MAX_RETRIES = validationMaxRetries;
    }
    /**
     * Get the API key
     * @returns The API key
     */
    getApiKey() {
        return this.API_KEY;
    }
    /**
     * Get the maximum number of retries for LLM calls
     * @returns The maximum number of retries
     */
    getMaxRetries() {
        return this.MAX_RETRIES;
    }
    /**
     * Get the commit mode
     * @returns The commit mode
     */
    getMode() {
        return this.MODE;
    }
    /**
     * Get the model name
     * @returns The model name
     */
    getModel() {
        return this.MODEL;
    }
    /**
     * Get the LLM provider
     * @returns The LLM provider
     */
    getProvider() {
        return this.PROVIDER;
    }
    /**
     * Get the maximum number of retries for validation fixes
     * @returns The maximum number of retries for validation
     */
    getValidationMaxRetries() {
        return this.VALIDATION_MAX_RETRIES;
    }
    /**
     * Check if configuration is in auto mode
     * @returns True if in auto mode
     */
    isAutoMode() {
        return this.MODE === "auto";
    }
    /**
     * Check if configuration is in manual mode
     * @returns True if in manual mode
     */
    isManualMode() {
        return this.MODE === "manual";
    }
    /**
     * Create a new configuration with a different mode
     * @param mode - The new mode
     * @returns New configuration with the updated mode
     */
    withMode(mode) {
        return new LLMConfiguration(this.PROVIDER, this.API_KEY, mode, this.MODEL, this.MAX_RETRIES, this.VALIDATION_MAX_RETRIES);
    }
    /**
     * Create a new configuration with updated model
     */
    withModel(model) {
        return new LLMConfiguration(this.PROVIDER, this.API_KEY, this.MODE, model, this.MAX_RETRIES, this.VALIDATION_MAX_RETRIES);
    }
}

exports.LLMConfiguration = LLMConfiguration;
//# sourceMappingURL=llm-configuration.entity.js.map
