'use strict';

/**
 * Value object representing a commit message header
 */
class CommitHeader {
    SCOPE;
    SUBJECT;
    TYPE;
    constructor(type, subject, scope) {
        if (!type || type.trim().length === 0) {
            throw new Error("Commit type cannot be empty");
        }
        if (!subject || subject.trim().length === 0) {
            throw new Error("Commit subject cannot be empty");
        }
        this.TYPE = type.trim();
        this.SUBJECT = subject.trim();
        this.SCOPE = scope?.trim();
    }
    /**
     * Check if two headers are equal
     */
    equals(other) {
        return this.TYPE === other.getType() && this.SCOPE === other.getScope() && this.SUBJECT === other.getSubject();
    }
    /**
     * Get the commit scope
     */
    getScope() {
        return this.SCOPE;
    }
    /**
     * Get the commit subject
     */
    getSubject() {
        return this.SUBJECT;
    }
    /**
     * Get the commit type
     */
    getType() {
        return this.TYPE;
    }
    /**
     * Format the header as a string
     */
    toString() {
        if (this.SCOPE) {
            return `${this.TYPE}(${this.SCOPE}): ${this.SUBJECT}`;
        }
        return `${this.TYPE}: ${this.SUBJECT}`;
    }
}

exports.CommitHeader = CommitHeader;
//# sourceMappingURL=commit-header.value-object.js.map
