import type { ICommitValidationResult, ICommitValidator } from "../../application/interface/commit-validator.interface.js";
import type { ILlmPromptContext, ILlmService } from "../../application/interface/llm-service.interface.js";
import type { CommitMessage } from "../../domain/entity/commit-message.entity.js";
import type { LLMConfiguration } from "../../domain/entity/llm-configuration.entity.js";
/**
 * Commitlint implementation of the commit validator
 */
export declare class CommitlintValidatorService implements ICommitValidator {
    private readonly LLM_SERVICES?;
    private llmConfiguration?;
    constructor(llmServices?: Array<ILlmService>);
    /**
     * Attempt to fix a commit message based on validation errors
     * @param message - The commit message to fix
     * @param validationResult - The validation result containing errors
     * @param context - Optional original context for LLM-based fixing
     * @returns Promise resolving to the fixed commit message or null if unfixable
     */
    fix(message: CommitMessage, validationResult: ICommitValidationResult, context?: ILlmPromptContext): Promise<CommitMessage | null>;
    /**
     * Set the LLM configuration for context-aware fixing
     * @param configuration - The LLM configuration
     */
    setLLMConfiguration(configuration: LLMConfiguration): void;
    /**
     * Validate a commit message using commitlint
     * @param message - The commit message to validate
     * @returns Promise resolving to the validation result
     */
    validate(message: CommitMessage): Promise<ICommitValidationResult>;
    /**
     * Wrap text to ensure no line exceeds the specified length
     * @param text - The text to wrap
     * @param maxLength - Maximum line length
     * @returns The wrapped text
     */
    private wrapText;
}
//# sourceMappingURL=commitlint-validator.service.d.ts.map