import type { ICommandService } from "../../application/interface/command-service.interface.js";
import type { ICommitRepository } from "../../application/interface/commit-repository.interface.js";
import type { CommitMessage } from "../../domain/entity/commit-message.entity.js";
/**
 * Git implementation of the commit repository
 */
export declare class GitCommitRepository implements ICommitRepository {
    private readonly COMMAND_SERVICE;
    constructor(commandService: ICommandService);
    /**
     * Create a commit with the given message
     * @param message - The commit message
     * @returns Promise that resolves when the commit is created
     */
    commit(message: CommitMessage): Promise<void>;
    /**
     * Get the current branch name
     * @returns Promise resolving to the current branch name
     */
    getCurrentBranch(): Promise<string>;
    /**
     * Get the staged diff
     * @returns Promise resolving to the staged diff
     */
    getStagedDiff(): Promise<string>;
    /**
     * Get the list of staged files
     * @returns Promise resolving to the list of staged files
     */
    getStagedFiles(): Promise<Array<string>>;
    /**
     * Check if there are staged changes
     * @returns Promise resolving to true if there are staged changes
     */
    hasStagedChanges(): Promise<boolean>;
}
//# sourceMappingURL=git-commit.repository.d.ts.map