import type { ILlmPromptContext, ILlmService } from "../../application/interface/llm-service.interface.js";
import type { LLMConfiguration } from "../../domain/entity/llm-configuration.entity.js";
import { CommitMessage } from "../../domain/entity/commit-message.entity.js";
/**
 * Ollama implementation of the LLM service
 */
export declare class OllamaLlmService implements ILlmService {
    /**
     * Generate a commit message using Ollama
     * @param context - The context for generating the commit message
     * @param configuration - The LLM configuration
     * @returns Promise resolving to the generated commit message
     */
    generateCommitMessage(context: ILlmPromptContext, configuration: LLMConfiguration): Promise<CommitMessage>;
    /**
     * Check if the service supports the given configuration
     * @param configuration - The LLM configuration to check
     * @returns True if the service supports the configuration
     */
    supports(configuration: LLMConfiguration): boolean;
    /**
     * Build the system prompt for Ollama
     * @param context - The prompt context
     * @returns The system prompt
     */
    private buildSystemPrompt;
    /**
     * Build the user prompt for Ollama
     * @param context - The prompt context
     * @returns The user prompt
     */
    private buildUserPrompt;
    /**
     * Format commitlint rules into human-readable instructions
     * @param rules - The commitlint rules object
     * @returns Formatted rules as string
     */
    private formatCommitlintRules;
    /**
     * Parse the commit message from the LLM response
     * @param content - The response content
     * @returns The parsed commit message
     */
    private parseCommitMessage;
}
//# sourceMappingURL=ollama-llm.service.d.ts.map