import type { CommitMessage } from "../../domain/entity/commit-message.entity.js";
import type { ICommitValidationResult, ICommitValidator } from "../interface/commit-validator.interface.js";
import type { ILlmPromptContext } from "../interface/llm-service.interface.js";
/**
 * Use case for validating and fixing commit messages
 */
export declare class ValidateCommitMessageUseCase {
    private readonly DEFAULT_MAX_RETRIES;
    private readonly VALIDATOR;
    constructor(validator: ICommitValidator, defaultMaxRetries?: number);
    /**
     * Execute the validation and optional fixing of a commit message
     * @param message - The commit message to validate
     * @param shouldAttemptFix - Whether to attempt to fix validation errors
     * @param maxRetries - Maximum number of fix attempts
     * @param context - Optional context for fixing
     * @returns Promise resolving to the validated/fixed message or null if unfixable
     */
    execute(message: CommitMessage, shouldAttemptFix?: boolean, maxRetries?: number, context?: ILlmPromptContext): Promise<CommitMessage | null>;
    /**
     * Validate a commit message
     * @param message - The commit message to validate
     * @returns Promise resolving to the validation result
     */
    validate(message: CommitMessage): Promise<ICommitValidationResult>;
}
//# sourceMappingURL=validate-commit-message.use-case.d.ts.map