/**
 * Entity representing a complete commit message
 */
class CommitMessage {
    BODY;
    HEADER;
    constructor(header, body) {
        this.HEADER = header;
        this.BODY = body;
    }
    /**
     * Get the commit body
     */
    getBody() {
        return this.BODY;
    }
    /**
     * Get the commit header
     */
    getHeader() {
        return this.HEADER;
    }
    /**
     * Check if the commit has a breaking change
     */
    hasBreakingChange() {
        return this.BODY.hasBreakingChange();
    }
    /**
     * Format the complete commit message
     */
    toString() {
        const parts = [this.HEADER.toString()];
        if (!this.BODY.isEmpty()) {
            parts.push(this.BODY.toString());
        }
        return parts.join("\n\n");
    }
    /**
     * Create a new commit message with updated body
     */
    withBody(body) {
        return new CommitMessage(this.HEADER, body);
    }
    /**
     * Create a new commit message with updated header
     */
    withHeader(header) {
        return new CommitMessage(header, this.BODY);
    }
}

export { CommitMessage };
//# sourceMappingURL=commit-message.entity.js.map
